===========================================
AIGC && LLM
===========================================

.. toctree::
    :maxdepth: 1

    stable_diffusion_lora/stable_diffusion_lora
    chatglm2_finetune/chatglm2_finetune
    baichuan2_finetune/baichuan2_finetune
